@@ -2,13 +2,14 @@ import requests
 import json
 import time
 import os
+import re
 
 import quantum_lab.resources as res
 
 class quantum_lab():
 
     def __init__(self,
-            resourceId: int,
+            resourceId: str,
             volumeName: str
         ):
         self.userID = os.environ["QCC_USER_ID"]
@@ -16,10 +17,12 @@ class quantum_lab():
         # self.shot = shot
         self.resourceId = resourceId
         # self.filePath = filePath
+        self.namespace = re.sub(r"[^\uAC00-\uD7A30-9a-zA-Z\s]", "", os.environ["QCC_USER_ID"].split('@')[0])
+        print("[NAMESPACE] ", self.namespace)
         self.volumeName = volumeName
         self.volumePath = self.getDirpath(volumeName)
         self.resourceName = res.getResourceName(resourceId)
-        self.url = "http://job-management.qcc.svc.cluster.local"
+        self.url = "http://quantum-job-management.qcc.svc.cluster.local:8080"
 
         if not isinstance(self.volumePath, str):
             raise ValueError(f"[ERROR] Volume {volumeName} not found in home. -> (/home/jovyan)")
@@ -49,32 +52,33 @@ class quantum_lab():
             uploadType: str, 
             shot: int, 
             fileName: str, 
-            timeout = 120
+            timeout = 10
         ):
         ## check file.
         filePath = ""
         fileList = os.listdir(self.volumePath)
         for files in fileList:
             if files == fileName:
-                filePath = f"{self.volumePath}/{fileName}"
-
+                filePath = f"/mnt/{self.namespace}/{self.volumeName}/{fileName}"
         if filePath == "":
-            raise ValueError(f"[ERROR]File {fileName} not found.")
+            raise ValueError(f"[ERROR] File {fileName} not found.")
 
-        url_path = f"{self.url}/qcc/notebook/job"
+        print("[FilePath] ", filePath)
+        url_path = f"{self.url}/v1/jobs"
 
         headers = {
             "Content-Type": "application/json",
-            "email": self.userID,
+            "emailId": self.userID,
         }
 
         body = json.dumps({
-            "uploadType": uploadType,
-            "shot": shot,
-            "resourceId": self.resourceId,
+            "resource": {
+                "id": self.resourceID,
+                "name": self.resourceName
+            },
+            "type": uploadType,
             "filePath": filePath,
-            "volumeName": self.volumeName,
-            "resourceName": self.resourceName
+            "shot": shot,
         })
 
         response = requests.post(f"{url_path}", headers=headers, data=body) 
@@ -84,16 +88,16 @@ class quantum_lab():
         data = response.json()
         
         print("{:<6} {:<15}".format("ID", "Created Status"))
-        print("{:<6} {:<15}".format(data["id"], 'Success' if data["status"] else 'Fail'))
+        print("{:<6} {:<15}".format(data["id"], data["status"]))
 
         jobID = data["id"]
 
         time_num = 0
         while True:
             time.sleep(1)
-            response = requests.get(f"{self.url}/qcc/notebook/job/{jobID}", headers=headers) 
+            response = requests.get(f"{self.url}/v1/jobs/{jobID}", headers=headers) 
             data = response.json()
-            p_status = data["jobStatus"]
+            p_status = data["status"]
             print(f"Time: {time_num} / Job Status: {p_status}        ", end='\r')
             if p_status == "Success" or p_status == "Failed":
                 break
@@ -119,7 +123,7 @@ class quantum_lab():
                 filePath = f"{self.volumePath}/{fileName}"
 
         if filePath == "":
-            raise ValueError(f"[ERROR]File {fileName} not found.")
+            raise ValueError(f"[ERROR] File {fileName} not found.")
 
         url_path = f"{self.url}/qcc/notebook/job"
 
@@ -150,11 +154,11 @@ class quantum_lab():
         return data["jobId"]
 
     def getList(self, limit = 0):
-        url_path = f"{self.url}/qcc/notebook/jobs"
+        url_path = f"{self.url}/v1/jobs"
 
         headers = {
             "Content-Type": "application/json",
-            "email": self.userID,
+            "emailId": self.userID,
         }
         response = requests.get(f"{url_path}",headers=headers)
         
@@ -163,41 +167,37 @@ class quantum_lab():
         
         data = response.json()
 
-        print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
+        print("{:<5} {:<12} {:<9} {:<5} {:<10} {:<20} {:<30}".format(
             "ID", 
-            "JobID", 
-            "ResourceID", 
+            # "JobID", 
+            # "ResourceID", 
             "ResourceName", 
-            "RegStatus", 
             "Status", 
             "Shot",
-            "UploadType",
+            "Type",
             "FilePath", 
-            "CreatedAt",
-            "RunningAt"
+            "CreatedAt"
             )
         )
         index = 0
-        for ele in data["jobs"]:
-            print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
+        for ele in data["content"]:
+            print("{:<5} {:<12} {:<9} {:<5} {:<10} {:<20} {:<30}".format(
                 ele["id"], 
-                ele["jobId"], 
-                ele["resourceId"], 
-                ele["resourceName"], 
-                'True' if ele["jobRegStatus"] else 'False', 
-                'NotReady' if ele["jobStatus"] is None else ele["jobStatus"],
-                ele["jobShot"],
-                ele["jobUploadType"],
-                ele["jobFilePath"].split('/')[-1],
-                ele["createdAt"],
-                'NotReady' if ele["runningAt"] is None else ele["runningAt"]
+                # ele["jobId"], 
+                # ele["resourceId"], 
+                ele["resource"]["name"], 
+                ele["status"],
+                ele["shot"],
+                ele["type"],
+                ele["filePath"].split('/')[-1],
+                ele["createdAt"]
                 )
             )
             index += 1 
             if limit != 0 and index > limit:
                 break
 
-        return data["jobs"]
+        return 1
 
     def getJob(self, id: int):
         url_path = f"{self.url}/qcc/notebook/job/{id}"
