@@ -10,12 +10,17 @@ def getResource():
     url = "http://quantum-resource.qcc.svc.cluster.local:8080"
     url_path = f"{url}/v1/resources"
 
-    params = {
-        "page": -1,
-        "size": 0
+    headers = {
+            "Content-Type": "application/json",
     }
 
-    response = requests.get(f"{url_path}", params=params)
+    params = {
+        "page": 0,
+        "size": 10
+    }
+
+
+    response = requests.get(f"{url_path}", params=params, headers=headers)
     
     if response.status_code != 200:
         return error_handler(response)
